% Generazione e importazione di dati con il software xFoil
% Script elaborato da Alessandro Masullo, 03/12/2012
% Web: http://www.wirgilio.it
%
% Questo script crea un file di comandi per xFoil, lo esegue e importa i
% risultati nel workspace.
% Una cartella "dati" viene creata per includere i risultati di xFoil
% Un file di testo "comandi.dat" contiene i comandi che vengono fatti
% eseguire ad xFoil. In particolare viene esportato il diagramma del
% coefficiente di pressione di un NACA 4412 tra alfa -10 e alfa 15 con
% passo 0.5 a Reynolds 10^6
clc; clear;
%% Scrittura dei dati
% Crea una cartella per contenere i risultati di xFoil
if not(isdir('./dati')), mkdir('./dati'); end

% Comandi di xFoil
alfa = -10:0.5:15;
N = length(alfa);

comandi = {
    'NACA 4412'
    'OPER'
    'RE 1e6'
    'VISC ON'
    sprintf(['ALFA %.3f\n' ...
             'CPWR ./dati/cp(%d).dat\n'], [alfa; 1:N])
    'QUIT'
};

% Scrive i comandi nel file
id = fopen('comandi.dat', 'w+');
fprintf(id, '%s\n', comandi{:});
fclose(id);

% Esegue xfoil
!xfoil.exe < comandi.dat

%% Legge i risultati
% Apre in sequenza tutti i file generati da xfoil e li mette in un cell
% array
dati = cell(1, N);
for i = 1:N
    % La variabile foo  di appoggio e serve a importare il solo contenuto
    % numerico dei file generati da xfoil
    foo = importdata(sprintf('./dati/cp(%d).dat', i), ' ', 1);
    dati{i} = foo.data(:, :);
end

%% Post-processing
figure(1)
for i = 1:N
    plot(dati{i}(:, 1), dati{i}(:, 2), '-k')
    % Asse negativo verso il basso
    set(gca, 'ydir', 'reverse')
    % Calcola il cl da mettere nel titolo
    cl = trapz(dati{i}(:, 1), dati{i}(:, 2));
    title(sprintf('Diagramma del cp a cl = %.3f', cl))
    axis([0 1 -5 1])
    pause(0.5)
end